@@ -19,7 +19,7 @@ logger = Logger()
 
 
 def entrypoint(project):
-    branch_name = git.current_branch_name()
+    branch_name = git.current_branch_name(project)
 
     if not git.remote_branch_exists(project, branch_name):
         logger.warning(f"Non ho trovato il branch {branch_name} su GitHub")
