@@ -68,7 +68,7 @@ def get_build_url(repo, build_number):
     return None
 
 
-def get_tag_from_builds(repo):
+def get_tags_from_builds(repo):
     tags = []
     builds = requests.get(
         f"{baseurl}/api/repos/primait/{repo}/builds?per_page=100",
@@ -85,15 +85,22 @@ def get_tag_from_builds(repo):
 
 
 def get_build_from_tag(repo, tag):
-    builds = requests.get(
-        f"{baseurl}/api/repos/primait/{repo}/builds?per_page=100",
-        headers={"Authorization": f"Bearer {drone_token}"},
-    ).json()
+    attempts = 0
+    while attempts < 3:
+
+        builds = requests.get(
+            f"{baseurl}/api/repos/primait/{repo}/builds?per_page=100",
+            headers={"Authorization": f"Bearer {drone_token}"},
+        ).json()
+
+        for build in builds:
+            if build["event"] == "tag":
+                if build["ref"].replace("refs/tags/", "") == tag:
+                    return build["number"]
+
+        time.sleep(2)
+        attempts += 1
 
-    for build in builds:
-        if build["event"] == "tag":
-            if build["ref"].replace("refs/tags/", "") == tag:
-                return build["number"]
     return None
 
 
